@@ -216,9 +216,9 @@ pln_dropoff(list, ip, tx, ty, ptr, type)
                         xyas(((struct sctstr *)ptr)->sct_x,
 			((struct sctstr *)ptr)->sct_y, player->cnum));
 		if (amt > 0 &&
-		    setmap(player->map, ((struct sctstr *)ptr)->sct_x,
+		    map_set(player->cnum, ((struct sctstr *)ptr)->sct_x,
 			   ((struct sctstr *)ptr)->sct_y, 'X', 0))
-			ef_write(EF_MAP, player->cnum, player->map);
+			writemap(player->cnum);
 		putsect((struct sctstr *) ptr);
 	}else{
 		there = getvar(ip->i_vtype, ptr, type) + amt;
@@ -844,8 +844,8 @@ coord	x,y;
 		}
 	}
 
-	if (found && setmap(player->map, sect.sct_x, sect.sct_y, 'X', 0))
-		ef_write(EF_MAP, player->cnum, player->map);
+	if (found && map_set(player->cnum, sect.sct_x, sect.sct_y, 'X', 0))
+		writemap(player->cnum);
 	putvar(V_MINE, mines_there, (s_char *)&sect, EF_SECTOR);
 	putsect(&sect);
 }
@@ -1058,3 +1058,13 @@ pln_damage(pp, x, y, type, nukedamp)
 		dam *= 2;
 	return dam;
 }
+
+int
+pln_identchance(pp, hardtarget, type)
+	struct	plnstr *pp;
+	int	hardtarget;
+	int	type;
+{
+	double	misschance = (100.0-pln_hitchance(pp, hardtarget, type))/100.0;
+	return (int)(100 - 100 * misschance * misschance);
+}
