@@ -222,10 +222,10 @@ shp_sweep(ship_list, verbose, actor)
 				mpr(actor, "Sweep...\n");
 				mines--;
 				shells = min(max, shells + 1);
-				changed |= msetmap(actor,
+				changed |= map_set(actor,
 						   sect.sct_x,
 						   sect.sct_y,
-						   'X');
+						   'X', 0);
 			}
 		}
 		putvar(V_MINE, mines, (s_char *)&sect, EF_SECTOR);
@@ -234,7 +234,7 @@ shp_sweep(ship_list, verbose, actor)
 		putsect(&sect);
 	}
 	if (changed)
-		ef_write(EF_MAP, player->cnum, player->map);
+		writemap(actor);
 }
 
 int
@@ -248,6 +248,7 @@ shp_check_mines(ship_list)
 	int	mines;
 	int	changed = 0;
 	int	stopping = 0;
+	natid	actor = -1;
 
         for (qp=ship_list->q_back;qp!=ship_list;qp=next) {
                 next = qp->q_back;
@@ -260,10 +261,10 @@ shp_check_mines(ship_list)
 		if (chance(DMINE_HITCHANCE(mines))) {
 			shp_hit_mine(&mlp->ship, mlp->mcp);
 			mines--;
-			changed |= msetmap(mlp->ship.shp_own,
+			changed |= map_set(actor = mlp->ship.shp_own,
 					   sect.sct_x,
 					   sect.sct_y,
-					   'X');
+					   'X', 0);
 			putvar(V_MINE,mines,(s_char *)&sect,EF_SECTOR);
 			putsect(&sect);
 			putship(mlp->ship.shp_uid, (s_char *)&mlp->ship);
@@ -275,7 +276,7 @@ shp_check_mines(ship_list)
 		}
 	}
 	if (changed)
-		ef_write(EF_MAP, player->cnum, player->map);
+		writemap(actor);
 	return stopping;
 }
 
@@ -900,7 +901,7 @@ shp_path(together, shp, buf)
 		return 0;
 	}
 		
-	cp = (s_char *)bestownedpath(buf, player->map, shp->shp_x, shp->shp_y, d_sect.sct_x, d_sect.sct_y, ".=h", player->cnum, 1);
+	cp = (s_char *)bestownedpath(buf, player->bmap, shp->shp_x, shp->shp_y, d_sect.sct_x, d_sect.sct_y, ".=h", player->cnum, 1);
 	if (!cp) {
 		mpr(shp->shp_own, "No all-sea path from %s to %s!\n",
 		    xyas(shp->shp_x,shp->shp_y,player->cnum),
