@@ -53,6 +53,11 @@ struct	sctstr {
 	u_char	sct_nv;		/* current number of variables */
 	u_char	sct_vtype[MAXSCTV];
 	u_short	sct_vamt[MAXSCTV];
+#ifndef SMALL_SERVER
+	s_char	sct_sparec;	/* not used */
+	int	sct_sparei;	/* not used */
+	long	sct_sparel;	/* not used */
+#endif /* SMALL_SERVER */
 };
 
 struct	dchrstr	{
